summaryrefslogtreecommitdiff
path: root/libavcodec
diff options
context:
space:
mode:
authorMåns Rullgård <mans@mansr.com>2008-12-17 00:54:54 +0000
committerMåns Rullgård <mans@mansr.com>2008-12-17 00:54:54 +0000
commita2fc0f6a6ddf884ace3c96a0d4f09f0932e6db32 (patch)
tree44b807b924e29465a6aed924fcb53c719a83a956 /libavcodec
parent2600f8c86dcaa411a0485b1518e5e1592374aaf6 (diff)
ARM: replace "armv4l" with "arm"
Originally committed as revision 16179 to svn://svn.ffmpeg.org/ffmpeg/trunk
Diffstat (limited to 'libavcodec')
-rw-r--r--libavcodec/Makefile38
-rw-r--r--libavcodec/arm/asm.S (renamed from libavcodec/armv4l/asm.S)0
-rw-r--r--libavcodec/arm/dsputil_arm.c (renamed from libavcodec/armv4l/dsputil_arm.c)4
-rw-r--r--libavcodec/arm/dsputil_arm_s.S (renamed from libavcodec/armv4l/dsputil_arm_s.S)2
-rw-r--r--libavcodec/arm/dsputil_iwmmxt.c (renamed from libavcodec/armv4l/dsputil_iwmmxt.c)0
-rw-r--r--libavcodec/arm/dsputil_iwmmxt_rnd_template.c (renamed from libavcodec/armv4l/dsputil_iwmmxt_rnd_template.c)0
-rw-r--r--libavcodec/arm/dsputil_neon.c (renamed from libavcodec/armv4l/dsputil_neon.c)0
-rw-r--r--libavcodec/arm/dsputil_neon_s.S (renamed from libavcodec/armv4l/dsputil_neon_s.S)0
-rw-r--r--libavcodec/arm/dsputil_vfp.S (renamed from libavcodec/armv4l/dsputil_vfp.S)0
-rw-r--r--libavcodec/arm/float_arm_vfp.c (renamed from libavcodec/armv4l/float_arm_vfp.c)0
-rw-r--r--libavcodec/arm/h264dsp_neon.S (renamed from libavcodec/armv4l/h264dsp_neon.S)0
-rw-r--r--libavcodec/arm/h264idct_neon.S (renamed from libavcodec/armv4l/h264idct_neon.S)0
-rw-r--r--libavcodec/arm/jrevdct_arm.S (renamed from libavcodec/armv4l/jrevdct_arm.S)0
-rw-r--r--libavcodec/arm/mathops.h (renamed from libavcodec/armv4l/mathops.h)6
-rw-r--r--libavcodec/arm/mpegvideo_arm.c (renamed from libavcodec/armv4l/mpegvideo_arm.c)2
-rw-r--r--libavcodec/arm/mpegvideo_armv5te.c (renamed from libavcodec/armv4l/mpegvideo_armv5te.c)0
-rw-r--r--libavcodec/arm/mpegvideo_armv5te_s.S (renamed from libavcodec/armv4l/mpegvideo_armv5te_s.S)0
-rw-r--r--libavcodec/arm/mpegvideo_iwmmxt.c (renamed from libavcodec/armv4l/mpegvideo_iwmmxt.c)0
-rw-r--r--libavcodec/arm/simple_idct_arm.S (renamed from libavcodec/armv4l/simple_idct_arm.S)0
-rw-r--r--libavcodec/arm/simple_idct_armv5te.S (renamed from libavcodec/armv4l/simple_idct_armv5te.S)0
-rw-r--r--libavcodec/arm/simple_idct_armv6.S (renamed from libavcodec/armv4l/simple_idct_armv6.S)0
-rw-r--r--libavcodec/arm/simple_idct_neon.S (renamed from libavcodec/armv4l/simple_idct_neon.S)0
-rw-r--r--libavcodec/bitstream.h4
-rw-r--r--libavcodec/dct-test.c4
-rw-r--r--libavcodec/dsputil.c2
-rw-r--r--libavcodec/dsputil.h4
-rw-r--r--libavcodec/mathops.h4
-rw-r--r--libavcodec/mpegvideo.c4
-rw-r--r--libavcodec/mpegvideo.h2
29 files changed, 38 insertions, 38 deletions
diff --git a/libavcodec/Makefile b/libavcodec/Makefile
index 20ed99143e..a78dfa2b03 100644
--- a/libavcodec/Makefile
+++ b/libavcodec/Makefile
@@ -429,29 +429,29 @@ OBJS-$(ARCH_ALPHA) += alpha/dsputil_alpha.o \
alpha/mpegvideo_alpha.o \
alpha/simple_idct_alpha.o \
-OBJS-$(ARCH_ARMV4L) += armv4l/dsputil_arm.o \
- armv4l/dsputil_arm_s.o \
- armv4l/jrevdct_arm.o \
- armv4l/mpegvideo_arm.o \
- armv4l/simple_idct_arm.o \
+OBJS-$(ARCH_ARM) += arm/dsputil_arm.o \
+ arm/dsputil_arm_s.o \
+ arm/jrevdct_arm.o \
+ arm/mpegvideo_arm.o \
+ arm/simple_idct_arm.o \
-OBJS-$(HAVE_ARMV5TE) += armv4l/mpegvideo_armv5te.o \
- armv4l/mpegvideo_armv5te_s.o \
- armv4l/simple_idct_armv5te.o \
+OBJS-$(HAVE_ARMV5TE) += arm/mpegvideo_armv5te.o \
+ arm/mpegvideo_armv5te_s.o \
+ arm/simple_idct_armv5te.o \
-OBJS-$(HAVE_ARMV6) += armv4l/simple_idct_armv6.o \
+OBJS-$(HAVE_ARMV6) += arm/simple_idct_armv6.o \
-OBJS-$(HAVE_ARMVFP) += armv4l/dsputil_vfp.o \
- armv4l/float_arm_vfp.o \
+OBJS-$(HAVE_ARMVFP) += arm/dsputil_vfp.o \
+ arm/float_arm_vfp.o \
-OBJS-$(HAVE_IWMMXT) += armv4l/dsputil_iwmmxt.o \
- armv4l/mpegvideo_iwmmxt.o \
+OBJS-$(HAVE_IWMMXT) += arm/dsputil_iwmmxt.o \
+ arm/mpegvideo_iwmmxt.o \
-OBJS-$(HAVE_NEON) += armv4l/dsputil_neon.o \
- armv4l/dsputil_neon_s.o \
- armv4l/h264dsp_neon.o \
- armv4l/h264idct_neon.o \
- armv4l/simple_idct_neon.o \
+OBJS-$(HAVE_NEON) += arm/dsputil_neon.o \
+ arm/dsputil_neon_s.o \
+ arm/h264dsp_neon.o \
+ arm/h264idct_neon.o \
+ arm/simple_idct_neon.o \
OBJS-$(ARCH_BFIN) += bfin/dsputil_bfin.o \
bfin/fdct_bfin.o \
@@ -499,7 +499,7 @@ TESTS-$(CONFIG_OLDSCALER) += imgresample-test$(EXESUF)
TESTS-$(ARCH_X86) += i386/cpuid-test$(EXESUF) motion-test$(EXESUF)
CLEANFILES = apiexample$(EXESUF)
-DIRS = alpha armv4l bfin i386 mlib ppc ps2 sh4 sparc
+DIRS = alpha arm bfin i386 mlib ppc ps2 sh4 sparc
include $(SUBDIR)../subdir.mak
diff --git a/libavcodec/armv4l/asm.S b/libavcodec/arm/asm.S
index e2595f4789..e2595f4789 100644
--- a/libavcodec/armv4l/asm.S
+++ b/libavcodec/arm/asm.S
diff --git a/libavcodec/armv4l/dsputil_arm_s.S b/libavcodec/arm/dsputil_arm_s.S
index ba06f3740f..639b7b8af8 100644
--- a/libavcodec/armv4l/dsputil_arm_s.S
+++ b/libavcodec/arm/dsputil_arm_s.S
@@ -1,5 +1,5 @@
@
-@ ARMv4L optimized DSP utils
+@ ARMv4 optimized DSP utils
@ Copyright (c) 2004 AGAWA Koji <i (AT) atty (DOT) jp>
@
@ This file is part of FFmpeg.
diff --git a/libavcodec/armv4l/dsputil_iwmmxt.c b/libavcodec/arm/dsputil_iwmmxt.c
index 3d6260b056..3d6260b056 100644
--- a/libavcodec/armv4l/dsputil_iwmmxt.c
+++ b/libavcodec/arm/dsputil_iwmmxt.c
diff --git a/libavcodec/armv4l/dsputil_iwmmxt_rnd_template.c b/libavcodec/arm/dsputil_iwmmxt_rnd_template.c
index 35a5a9b8b4..35a5a9b8b4 100644
--- a/libavcodec/armv4l/dsputil_iwmmxt_rnd_template.c
+++ b/libavcodec/arm/dsputil_iwmmxt_rnd_template.c
diff --git a/libavcodec/armv4l/dsputil_neon.c b/libavcodec/arm/dsputil_neon.c
index 5204c50e37..5204c50e37 100644
--- a/libavcodec/armv4l/dsputil_neon.c
+++ b/libavcodec/arm/dsputil_neon.c
diff --git a/libavcodec/armv4l/dsputil_neon_s.S b/libavcodec/arm/dsputil_neon_s.S
index 1241cdc9ef..1241cdc9ef 100644
--- a/libavcodec/armv4l/dsputil_neon_s.S
+++ b/libavcodec/arm/dsputil_neon_s.S
diff --git a/libavcodec/armv4l/dsputil_vfp.S b/libavcodec/arm/dsputil_vfp.S
index 04c8014e1e..04c8014e1e 100644
--- a/libavcodec/armv4l/dsputil_vfp.S
+++ b/libavcodec/arm/dsputil_vfp.S
diff --git a/libavcodec/armv4l/float_arm_vfp.c b/libavcodec/arm/float_arm_vfp.c
index 5598aa9c02..5598aa9c02 100644
--- a/libavcodec/armv4l/float_arm_vfp.c
+++ b/libavcodec/arm/float_arm_vfp.c
diff --git a/libavcodec/armv4l/h264dsp_neon.S b/libavcodec/arm/h264dsp_neon.S
index 39a8daf62e..39a8daf62e 100644
--- a/libavcodec/armv4l/h264dsp_neon.S
+++ b/libavcodec/arm/h264dsp_neon.S
diff --git a/libavcodec/armv4l/h264idct_neon.S b/libavcodec/arm/h264idct_neon.S
index b7ef2f4519..b7ef2f4519 100644
--- a/libavcodec/armv4l/h264idct_neon.S
+++ b/libavcodec/arm/h264idct_neon.S
diff --git a/libavcodec/armv4l/jrevdct_arm.S b/libavcodec/arm/jrevdct_arm.S
index b77315b0f5..b77315b0f5 100644
--- a/libavcodec/armv4l/jrevdct_arm.S
+++ b/libavcodec/arm/jrevdct_arm.S
diff --git a/libavcodec/armv4l/mathops.h b/libavcodec/arm/mathops.h
index f8a3d6db40..e36316c76b 100644
--- a/libavcodec/armv4l/mathops.h
+++ b/libavcodec/arm/mathops.h
@@ -19,8 +19,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
-#ifndef AVCODEC_ARMV4L_MATHOPS_H
-#define AVCODEC_ARMV4L_MATHOPS_H
+#ifndef AVCODEC_ARM_MATHOPS_H
+#define AVCODEC_ARM_MATHOPS_H
#include <stdint.h>
#include "libavutil/common.h"
@@ -90,4 +90,4 @@ static inline av_const MUL16(int ra, int rb)
#endif
-#endif /* AVCODEC_ARMV4L_MATHOPS_H */
+#endif /* AVCODEC_ARM_MATHOPS_H */
diff --git a/libavcodec/armv4l/mpegvideo_arm.c b/libavcodec/arm/mpegvideo_arm.c
index 657fc03d5a..18faed2d36 100644
--- a/libavcodec/armv4l/mpegvideo_arm.c
+++ b/libavcodec/arm/mpegvideo_arm.c
@@ -25,7 +25,7 @@
void MPV_common_init_iwmmxt(MpegEncContext *s);
void MPV_common_init_armv5te(MpegEncContext *s);
-void MPV_common_init_armv4l(MpegEncContext *s)
+void MPV_common_init_arm(MpegEncContext *s)
{
/* IWMMXT support is a superset of armv5te, so
* allow optimized functions for armv5te unless
diff --git a/libavcodec/armv4l/mpegvideo_armv5te.c b/libavcodec/arm/mpegvideo_armv5te.c
index b213cf1de3..b213cf1de3 100644
--- a/libavcodec/armv4l/mpegvideo_armv5te.c
+++ b/libavcodec/arm/mpegvideo_armv5te.c
diff --git a/libavcodec/armv4l/mpegvideo_armv5te_s.S b/libavcodec/arm/mpegvideo_armv5te_s.S
index aaa252d3b7..aaa252d3b7 100644
--- a/libavcodec/armv4l/mpegvideo_armv5te_s.S
+++ b/libavcodec/arm/mpegvideo_armv5te_s.S
diff --git a/libavcodec/armv4l/mpegvideo_iwmmxt.c b/libavcodec/arm/mpegvideo_iwmmxt.c
index e816ac67c5..e816ac67c5 100644
--- a/libavcodec/armv4l/mpegvideo_iwmmxt.c
+++ b/libavcodec/arm/mpegvideo_iwmmxt.c
diff --git a/libavcodec/armv4l/simple_idct_arm.S b/libavcodec/arm/simple_idct_arm.S
index 16ade1f3da..16ade1f3da 100644
--- a/libavcodec/armv4l/simple_idct_arm.S
+++ b/libavcodec/arm/simple_idct_arm.S
diff --git a/libavcodec/armv4l/simple_idct_armv5te.S b/libavcodec/arm/simple_idct_armv5te.S
index 58040ec1ba..58040ec1ba 100644
--- a/libavcodec/armv4l/simple_idct_armv5te.S
+++ b/libavcodec/arm/simple_idct_armv5te.S
diff --git a/libavcodec/armv4l/simple_idct_armv6.S b/libavcodec/arm/simple_idct_armv6.S
index 4f3330d223..4f3330d223 100644
--- a/libavcodec/armv4l/simple_idct_armv6.S
+++ b/libavcodec/arm/simple_idct_armv6.S
diff --git a/libavcodec/armv4l/simple_idct_neon.S b/libavcodec/arm/simple_idct_neon.S
index 376db0b534..376db0b534 100644
--- a/libavcodec/armv4l/simple_idct_neon.S
+++ b/libavcodec/arm/simple_idct_neon.S
diff --git a/libavcodec/bitstream.h b/libavcodec/bitstream.h
index 5a5db5c9f2..3e8f25ecd2 100644
--- a/libavcodec/bitstream.h
+++ b/libavcodec/bitstream.h
@@ -41,7 +41,7 @@
//#define ALT_BITSTREAM_WRITER
//#define ALIGNED_BITSTREAM_WRITER
#if !defined(LIBMPEG2_BITSTREAM_READER) && !defined(A32_BITSTREAM_READER) && !defined(ALT_BITSTREAM_READER)
-# ifdef ARCH_ARMV4L
+# ifdef ARCH_ARM
# define A32_BITSTREAM_READER
# else
# define ALT_BITSTREAM_READER
@@ -179,7 +179,7 @@ typedef struct RL_VLC_ELEM {
uint8_t run;
} RL_VLC_ELEM;
-#if defined(ARCH_SPARC) || defined(ARCH_ARMV4L) || defined(ARCH_MIPS) || defined(ARCH_BFIN)
+#if defined(ARCH_SPARC) || defined(ARCH_ARM) || defined(ARCH_MIPS) || defined(ARCH_BFIN)
#define UNALIGNED_STORES_ARE_BAD
#endif
diff --git a/libavcodec/dct-test.c b/libavcodec/dct-test.c
index a86109bdc0..53b4f3de14 100644
--- a/libavcodec/dct-test.c
+++ b/libavcodec/dct-test.c
@@ -123,7 +123,7 @@ struct algo algos[] = {
{"BFINidct", 1, ff_bfin_idct, idct, NO_PERM},
#endif
-#ifdef ARCH_ARMV4L
+#ifdef ARCH_ARM
{"SIMPLE-ARM", 1, simple_idct_ARM, idct, NO_PERM },
{"INT-ARM", 1, j_rev_dct_ARM, idct, MMX_PERM },
#ifdef HAVE_ARMV5TE
@@ -135,7 +135,7 @@ struct algo algos[] = {
#ifdef HAVE_NEON
{"SIMPLE-NEON", 1, ff_simple_idct_neon, idct, PARTTRANS_PERM },
#endif
-#endif /* ARCH_ARMV4L */
+#endif /* ARCH_ARM */
{ 0 }
};
diff --git a/libavcodec/dsputil.c b/libavcodec/dsputil.c
index a97fb1e2cd..386d54a4d5 100644
--- a/libavcodec/dsputil.c
+++ b/libavcodec/dsputil.c
@@ -4554,7 +4554,7 @@ void dsputil_init(DSPContext* c, AVCodecContext *avctx)
memset(c->avg_2tap_qpel_pixels_tab, 0, sizeof(c->avg_2tap_qpel_pixels_tab));
if (ENABLE_MMX) dsputil_init_mmx (c, avctx);
- if (ENABLE_ARMV4L) dsputil_init_armv4l(c, avctx);
+ if (ENABLE_ARM) dsputil_init_arm (c, avctx);
if (ENABLE_MLIB) dsputil_init_mlib (c, avctx);
if (ENABLE_VIS) dsputil_init_vis (c, avctx);
if (ENABLE_ALPHA) dsputil_init_alpha (c, avctx);
diff --git a/libavcodec/dsputil.h b/libavcodec/dsputil.h
index 1864cc70d6..c94e443c30 100644
--- a/libavcodec/dsputil.h
+++ b/libavcodec/dsputil.h
@@ -558,7 +558,7 @@ static inline int get_penalty_factor(int lambda, int lambda2, int type){
int mm_support(void);
void dsputil_init_alpha(DSPContext* c, AVCodecContext *avctx);
-void dsputil_init_armv4l(DSPContext* c, AVCodecContext *avctx);
+void dsputil_init_arm(DSPContext* c, AVCodecContext *avctx);
void dsputil_init_bfin(DSPContext* c, AVCodecContext *avctx);
void dsputil_init_mlib(DSPContext* c, AVCodecContext *avctx);
void dsputil_init_mmi(DSPContext* c, AVCodecContext *avctx);
@@ -593,7 +593,7 @@ static inline void emms(void)
void dsputil_init_pix_mmx(DSPContext* c, AVCodecContext *avctx);
-#elif defined(ARCH_ARMV4L)
+#elif defined(ARCH_ARM)
extern int mm_flags;
diff --git a/libavcodec/mathops.h b/libavcodec/mathops.h
index 817e4525c7..486eed7822 100644
--- a/libavcodec/mathops.h
+++ b/libavcodec/mathops.h
@@ -28,9 +28,9 @@
#include "i386/mathops.h"
-#elif defined(ARCH_ARMV4L)
+#elif defined(ARCH_ARM)
-#include "armv4l/mathops.h"
+#include "arm/mathops.h"
#elif defined(ARCH_POWERPC)
diff --git a/libavcodec/mpegvideo.c b/libavcodec/mpegvideo.c
index c603f66360..6560d6b5a1 100644
--- a/libavcodec/mpegvideo.c
+++ b/libavcodec/mpegvideo.c
@@ -129,8 +129,8 @@ int ff_dct_common_init(MpegEncContext *s)
MPV_common_init_mlib(s);
#elif defined(HAVE_MMI)
MPV_common_init_mmi(s);
-#elif defined(ARCH_ARMV4L)
- MPV_common_init_armv4l(s);
+#elif defined(ARCH_ARM)
+ MPV_common_init_arm(s);
#elif defined(HAVE_ALTIVEC)
MPV_common_init_altivec(s);
#elif defined(ARCH_BFIN)
diff --git a/libavcodec/mpegvideo.h b/libavcodec/mpegvideo.h
index c57a76164c..da08bb6ea4 100644
--- a/libavcodec/mpegvideo.h
+++ b/libavcodec/mpegvideo.h
@@ -684,7 +684,7 @@ void MPV_common_init_mmx(MpegEncContext *s);
void MPV_common_init_axp(MpegEncContext *s);
void MPV_common_init_mlib(MpegEncContext *s);
void MPV_common_init_mmi(MpegEncContext *s);
-void MPV_common_init_armv4l(MpegEncContext *s);
+void MPV_common_init_arm(MpegEncContext *s);
void MPV_common_init_altivec(MpegEncContext *s);
void ff_clean_intra_table_entries(MpegEncContext *s);
void ff_draw_horiz_band(MpegEncContext *s, int y, int h);
diff --git a/libavcodec/armv4l/dsputil_arm.c b/libavcodec/arm/dsputil_arm.c
index 7f6616ddf8..eaa6b9eb8d 100644
--- a/libavcodec/armv4l/dsputil_arm.c
+++ b/libavcodec/arm/dsputil_arm.c
@@ -1,5 +1,5 @@
/*
* ARMv4L optimized DSP utils
* Copyright (c) 2001 Lionel Ulmer.
*
* This file is part of FFmpeg.
@@ -121,7 +121,7 @@ int mm_support(void)
return ENABLE_IWMMXT * FF_MM_IWMMXT;
}
-void dsputil_init_armv4l(DSPContext* c, AVCodecContext *avctx)
+void dsputil_init_arm(DSPContext* c, AVCodecContext *avctx)
{
int idct_algo= avctx->idct_algo;
@@ -1,5 +1,5 @@
/*
- * ARMv4L optimized DSP utils
+ * ARM optimized DSP utils
* Copyright (c) 2001 Lionel Ulmer.
*